Module
------------------------

.. automodule:: flax.linen
.. currentmodule:: flax.linen

.. autoclass:: Module
   :members: setup, variable, param, bind, unbind, apply, init, init_with_output, copy, make_rng, sow, variables, Variable, __setattr__, tabulate, is_initializing, perturb, put_variable, has_variable, has_rng, lazy_init, get_variable, path, is_mutable_collection

.. autofunction:: apply
.. autofunction:: init
.. autofunction:: init_with_output
.. autofunction:: intercept_methods
